Authors
*******

* `Drew Engelson`_
* `Contributors`_
* Sanity checks by `Justin Quick`_
* Python encryption with crc from `Alon Swartz`_

.. _`Drew Engelson`: http://github.com/tomatohater
.. _`Contributors`: https://github.com/tomatohater/django-unfriendly/contributors/
.. _`Justin Quick`: http://github.com/justquick
.. _`Alon Swartz`: http://www.turnkeylinux.org/blog/python-symmetric-encryption
